from __future__ import print_function
from uuid import uuid4

from IPython.display import display_html, display_javascript
from jinja2 import Environment, PackageLoader


from jinja2 import Environment, PackageLoader, select_autoescape


__all__ = ['display_request']


templates = Environment(
    loader=PackageLoader('nbrequests', 'templates')
)


def display_request(r):
    rq_id = str(uuid4())
    rs_id = str(uuid4())
    html = templates.get_template('requests.html')
    display_html(html.render(r=r, rq_id=rq_id, rs_id=rs_id), raw=True)
    js_template = templates.get_template('requests.js')
    display_javascript(js_template.render(r=r, rq_id=rq_id, rs_id=rs_id), raw=True)





from setuptools import setup

setup(
    name='nbrequests',
    author='Kristian Perkins',
    author_email='khperkins@gmail.com',
    version='0.0.3',
    url='http://github.com/kristianperkins/nbrequests',
    py_modules=['nbrequests'],
    packages=['nbrequests'],
    description='',
    long_description=open('README.rst').read(),
    license='Apache 2.0',
    install_requires=open('requirements.txt').read().split(),
    classifiers=[
        'Environment :: Console',
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: Apache Software License',
	'Topic :: Utilities',
    ],
)
